pub fn load_resource_pack<P: AsRef<Path>>(path: P) -> Result<ResourcePack>Expand description
Load a resource pack from a file path (ZIP or directory).
pub fn load_resource_pack<P: AsRef<Path>>(path: P) -> Result<ResourcePack>Load a resource pack from a file path (ZIP or directory).